tests

package
v0.0.0-...-9489dbf Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 6, 2017 License: MPL-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DecodeRaw

func DecodeRaw(input string) interface{}

DecodeRaw supports testing NewConfig functions, which never receive the raw string, but instead get the interface{} parsed in the config package. This mimics the behavior of the config package, but bails if we've written bad test JSON

func DecodeRawToSlice

func DecodeRawToSlice(input string) []interface{}

DecodeRawToSlice supports testing NewConfig functions, which never receive the raw string, but instead get the []interface{} parsed in the config package. This mimics the behavior of the config package, but bails if we've written bad test JSON

Types

This section is empty.

Directories

Path Synopsis

Jump to